@@ -5,7 +5,6 @@ from typing import Union
 
 import numpy as np
 import pandas as pd
-from ipyleaflet import Map, ScaleControl, FullScreenControl, Circle, LayerGroup
 from scipy import signal, integrate
 from shapely.geometry import Point
 from tqdm.auto import tqdm
@@ -15,12 +14,13 @@ from pyridy.file import RDYFile
 from pyridy.osm.utils import convert_way_to_line_string, OSMResultNode
 from pyridy.processing import PostProcessor
 from pyridy.utils import LinearAccelerationSeries, GPSSeries
+from pyridy.widgets import Map
 
 logger = logging.getLogger(__name__)
 
 
 class ExcitationProcessor(PostProcessor):
-    def __init__(self, campaign: Campaign, f_s: int = 200, f_c: float = 0.1, order: int = 4,
+    def __init__(self, campaign: Campaign, f_s: int = 200, f_c: float = 1, order: int = 4,
                  p_thres: float = .025, p_dist: int = 50, osm_integration=True):
         """ The ExcitationProcessor performs a double integration of the acceleration data to calculate
         excitations. High-Pass Filters are applied to remove static offset and drift. Hence, the resulting
@@ -47,7 +47,8 @@ class ExcitationProcessor(PostProcessor):
         self.p_dist = p_dist
         self.osm_integration = osm_integration
 
-        self.b, self.a = signal.butter(self.order, 2 * self.f_c / self.f_s, 'high')  # High Pass (2*f_c/f_s)
+        self.b, self.a = signal.butter(self.order, self.f_c, 'high', analog=True)  # High Pass (2*f_c/f_s)
+        self.z, self.p = signal.bilinear(self.b, self.a, fs=self.f_s)
 
     def execute(self, axes: Union[str, list] = "z", intp_gps: bool = True, reset: bool = False):
         """ Executes the processor on the given axes
@@ -79,8 +80,8 @@ class ExcitationProcessor(PostProcessor):
         f: RDYFile
         for f in tqdm(self.campaign):
             if len(f.measurements[LinearAccelerationSeries]) == 0:
-                logger.warning("({f.filename}) LinearAccelerationSeries is empty, can't execute ExcitationProcessor "
-                               "on this file")
+                logger.warning("({}) LinearAccelerationSeries is empty, can't execute ExcitationProcessor "
+                               "on this file".format(f.filename))
                 continue
             else:
                 lin_acc_df = f.measurements[LinearAccelerationSeries].to_df()
@@ -107,15 +108,15 @@ class ExcitationProcessor(PostProcessor):
                         raise ValueError("axes must be 'x', 'y' or 'z', or list of these values")
 
                     # High pass filter first to remove static offset
-                    lin_acc_hp = signal.filtfilt(self.b, self.a, lin_acc, padlen=150)
+                    lin_acc_hp = signal.filtfilt(self.z, self.p, lin_acc, padlen=150)
 
                     # Integrate and High-Pass Filter
                     lin_v = integrate.cumtrapz(lin_acc_hp, t, initial=0)
-                    lin_v_hp = signal.filtfilt(self.b, self.a, lin_v, padlen=150)
+                    lin_v_hp = signal.filtfilt(self.z, self.p, lin_v, padlen=150)
                     df["lin_v_" + ax] = lin_v_hp
 
                     lin_s = integrate.cumtrapz(lin_v_hp, t, initial=0)
-                    lin_s_hp = signal.filtfilt(self.b, self.a, lin_s, padlen=150)
+                    lin_s_hp = signal.filtfilt(self.z, self.p, lin_s, padlen=150)
                     df["lin_s_" + ax] = lin_s_hp
 
                     # Peak nodes for OSM
@@ -165,33 +166,6 @@ class ExcitationProcessor(PostProcessor):
         pass
 
     def create_map(self, use_file_color=False) -> Map:
-        if not self.campaign.osm:
-            raise ValueError("Campaign has no OSM data!")
-
-        center = ((self.campaign.lat_sw + self.campaign.lat_ne) / 2,
-                  (self.campaign.lon_sw + self.campaign.lon_ne) / 2)
-
-        m = Map(center=center, zoom=12, scroll_wheel_zoom=True, basemap=config.OPEN_STREET_MAP_DE)
-        m.add_control(ScaleControl(position='bottomleft'))
-        m.add_control(FullScreenControl())
-
-        # Add map
-        m.add_layer(config.OPEN_RAILWAY_MAP)
-
-        circles = []
-        nodes = list(itertools.chain.from_iterable([w.attributes.get("results", []) for w in self.campaign.osm.ways]))
-
-        n: OSMResultNode
-        for n in nodes:
-            circle = Circle()
-            circle.location = n.lon, n.lat
-            circle.radius = 2
-            circle.color = n.f.color if use_file_color else n.color
-            circle.fill_color = n.f.color if use_file_color else n.color
-            circle.weight = 3
-            circle.fill_opacity = 0.1
-            circles.append(circle)
-
-        l_circles = LayerGroup(layers=circles)
-        m.add_layer(l_circles)
+        m = self.campaign.create_map(show_gps_tracks=True, show_railway_elements=False)
+        m.add_results_from_campaign(self.campaign, use_file_color=use_file_color)
         return m
