@@ -54,9 +54,9 @@ class Map(LeafletMap):
         self.add(self.railwaymap)
         self.railwaymap.opacity = 0.4
         # noinspection PyUnresolvedReferences
-        positron = basemap_to_tiles(basemaps.CartoDB.Positron)
-        positron.base = True
-        self.add(positron)
+        # positron = basemap_to_tiles(basemaps.CartoDB.Positron)
+        # positron.base = True
+        # self.add(positron)
 
     def add_measurements(self, campaign: 'Campaign') -> Union[None, List[LayerGroup]]:
         """ Add all GPS tracks from the campaign files to a Map
